From fb2217ac67706e4cbef69bea41041e2fb8b910e9 Mon Sep 17 00:00:00 2001
From: Eduardo Chappa <chappa@washington.edu>
Date: Thu, 23 Sep 2021 10:40:11 -0600
Subject: [PATCH]    * Alpine fails to build when given the --without-ssl
 configure      option due to an undefined value for DF_ENCRYPTION_RANGE.     
 Reported by David Morris.

---
 alpine/alpine.c               | 3 ++-
 alpine/confscroll.c           | 4 ++++
 doc/tech-notes/tech-notes.txt | 2 +-
 pith/conf.c                   | 8 ++++++++
 pith/conftype.h               | 2 ++
 pith/pine.hlp                 | 2 +-
 6 files changed, 18 insertions(+), 3 deletions(-)

diff --git a/alpine/alpine.c b/alpine/alpine.c
index 7ca1047..1523634 100644
--- a/alpine/alpine.c
+++ b/alpine/alpine.c
@@ -662,6 +662,7 @@ main(int argc, char **argv)
 	  }
     }
 
+#ifdef DF_ENCRYPTION_RANGE
     if(ps_global->VAR_ENCRYPTION_RANGE
 	&& ps_global->VAR_ENCRYPTION_RANGE[0]){
 	char *min_s, *max_s, *s;
@@ -727,7 +728,7 @@ main(int argc, char **argv)
            mail_parameters(NULL, SET_ENCRYPTION_RANGE_MAX, (void *) &max_v);
 	}
     }
-
+#endif /* DF_ENCRYPTION_RANGE */
 
     /*
      * setup alternative authentication driver preference for IMAP opens
diff --git a/alpine/confscroll.c b/alpine/confscroll.c
index 5e2817b..6a968a7 100644
--- a/alpine/confscroll.c
+++ b/alpine/confscroll.c
@@ -343,7 +343,9 @@ exclude_config_var(struct pine *ps, struct variable *var, int allow_hard_to_conf
       case V_GLOB_ADDRBOOK :
       case V_DISABLE_DRIVERS :
       case V_DISABLE_AUTHS :
+#ifdef DF_ENCRYPTION_RANGE
       case V_ENCRYPTION_RANGE :
+#endif /* DF_ENCRYPTION_RANGE */
       case V_REMOTE_ABOOK_METADATA :
       case V_REMOTE_ABOOK_HISTORY :
       case V_REMOTE_ABOOK_VALIDITY :
@@ -5778,7 +5780,9 @@ fix_side_effects(struct pine *ps, struct variable *var, int revert)
 		        var == &ps->vars[V_NEWS_SPEC] ||
 		        var == &ps->vars[V_DISABLE_DRIVERS] ||
 		        var == &ps->vars[V_DISABLE_AUTHS] ||
+#ifdef DF_ENCRYPTION_RANGE
 		        var == &ps->vars[V_ENCRYPTION_RANGE] ||
+#endif /* DF_ENCRYPTION_RANGE */
 #if !defined(_WINDOWS) || defined(ENABLE_WINDOWS_UNIXSSL_CERTS)
 			var == &ps->vars[V_SSLCAPATH] ||
 			var == &ps->vars[V_SSLCAFILE] ||
diff --git a/doc/tech-notes/tech-notes.txt b/doc/tech-notes/tech-notes.txt
index 48ea47b..58dc15f 100644
--- a/doc/tech-notes/tech-notes.txt
+++ b/doc/tech-notes/tech-notes.txt
@@ -1,7 +1,7 @@
 
                              Alpine Technical Notes
 
-   Version 2.24.2, May 2021
+   Version 2.25, September 2021
 
 Table of Contents
 
diff --git a/pith/conf.c b/pith/conf.c
index 452c6db..704c691 100644
--- a/pith/conf.c
+++ b/pith/conf.c
@@ -768,8 +768,10 @@ static struct variable variables[] = {
 	NULL,			cf_text_disable_drivers},
 {"disable-these-authenticators",	0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0,
 	NULL,			cf_text_disable_auths},
+#ifdef DF_ENCRYPTION_RANGE
 {"encryption-protocol-range",		0, 1, 0, 1, 1, 0, 0, 0, 0, 1, 0,
 	NULL,			cf_text_encryption_range},
+#endif /* DF_ENCRYPTION_RANGE */
 {"remote-abook-metafile",		0, 1, 0, 1, 0, 0, 0, 0, 1, 1, 0,
 	NULL,			cf_text_remote_abook_metafile},
 {"remote-abook-history",		0, 1, 0, 1, 1, 0, 0, 0, 0, 1, 0,
@@ -1631,7 +1633,9 @@ init_vars(struct pine *ps, void (*cmds_f) (struct pine *, char **))
 
     GLO_PRINTER			= cpystr(DF_DEFAULT_PRINTER);
     GLO_ELM_STYLE_SAVE		= cpystr(DF_ELM_STYLE_SAVE);
+#ifdef DF_ENCRYPTION_RANGE
     GLO_ENCRYPTION_RANGE	= cpystr(DF_ENCRYPTION_RANGE);
+#endif /* DF_ENCRYPTION_RANGE */
     GLO_SAVE_BY_SENDER		= cpystr(DF_SAVE_BY_SENDER);
     GLO_HEADER_IN_REPLY		= cpystr(DF_HEADER_IN_REPLY);
     GLO_INBOX_PATH		= cpystr("inbox");
@@ -2411,7 +2415,9 @@ init_vars(struct pine *ps, void (*cmds_f) (struct pine *, char **))
     set_current_val(&vars[V_FORCED_ABOOK_ENTRY], TRUE, TRUE);
     set_current_val(&vars[V_DISABLE_DRIVERS], TRUE, TRUE);
     set_current_val(&vars[V_DISABLE_AUTHS], TRUE, TRUE);
+#ifdef DF_ENCRYPTION_RANGE
     set_current_val(&vars[V_ENCRYPTION_RANGE], TRUE, TRUE);
+#endif /* DF_ENCRYPTION_RANGE */
 
     set_current_val(&vars[V_VIEW_HEADERS], TRUE, TRUE);
     /* strip spaces and colons */
@@ -7985,8 +7991,10 @@ config_help(int var, int feature)
 	return(h_config_disable_drivers);
       case V_DISABLE_AUTHS :
 	return(h_config_disable_auths);
+#ifdef DF_ENCRYPTION_RANGE
       case V_ENCRYPTION_RANGE :
 	return(h_config_encryption_range);
+#endif /* DF_ENCRYPTION_RANGE */
       case V_REMOTE_ABOOK_METADATA :
 	return(h_config_abook_metafile);
       case V_REPLY_STRING :
diff --git a/pith/conftype.h b/pith/conftype.h
index 5f2dd50..94dffcb 100644
--- a/pith/conftype.h
+++ b/pith/conftype.h
@@ -177,7 +177,9 @@ typedef	enum {    V_PERSONAL_NAME = 0
 		, V_NEW_VER_QUELL
 		, V_DISABLE_DRIVERS
 		, V_DISABLE_AUTHS
+#ifdef DF_ENCRYPTION_RANGE
 		, V_ENCRYPTION_RANGE
+#endif /* DF_ENCRYPTION_RANGE */
 		, V_REMOTE_ABOOK_METADATA
 		, V_REMOTE_ABOOK_HISTORY
 		, V_REMOTE_ABOOK_VALIDITY
diff --git a/pith/pine.hlp b/pith/pine.hlp
index 0c14206..fab964e 100644
--- a/pith/pine.hlp
+++ b/pith/pine.hlp
@@ -140,7 +140,7 @@ with help text for the config screen and the composer that didn't have any
 reasonable place to be called from.
 Dummy change to get revision in pine.hlp
 ============= h_revision =================
-Alpine Commit 592 2021-09-18 09:01:17
+Alpine Commit 593 2021-09-23 10:40:08
 ============= h_news =================
 <HTML>
 <HEAD>
-- 
2.11.4.GIT

